@@ -1,5 +1,6 @@
 
 from datetime import datetime
+import importlib
 import yaml
 import time
 import requests
@@ -23,6 +24,7 @@ class JobServer ():
   heartbeatInterval = 10
   configfile="/etc/mprov/jobserver.yaml"
   ip_address = ""
+  myaddress = ""
   plugin_dir = os.path.dirname(os.path.realpath(__file__)) + '/plugins/'
   jobmodules = []
   running_threads = {}
@@ -45,13 +47,24 @@ class JobServer ():
     # load our config
     self.load_config()
     
-    
     # set runonce if someone sent it to us.
     if 'runonce' in kwargs:
       self.runonce = kwargs['runonce']
       
+      
     if '-d' in set(sys.argv):
       self.register = False
+
+
+    if '-m' in set(sys.argv):
+      # -m overrides whatever is in the config.
+      # so we will re-write the self.jobmodules list
+      self.jobmodules= sys.argv[sys.argv.index('-m')+1].split(',')
+      # we are also going to specify runonce
+      self.runonce=True
+      # we also don't want to register with mPCC
+      self.register = False
+
     # Load Plugins. (plugins register job modules.)
     self.load_plugins()
 
@@ -151,6 +164,13 @@ class JobServer ():
             # if a thread of this plugin is not running, start one.
             if mod not in self.running_threads:
               # print ("Starting mod... " + mod)
+              # attempt to reload the module, just in case
+              #print(f"Starting {mod.replace('-', '_')}")
+              if f"mprov_jobserver.plugins.{mod.replace('-', '_')}" in sys.modules:
+                #reload
+                #print(f"Reload mprov_jobserver.plugins.{mod.replace('-', '_')}")
+                importlib.reload(sys.modules[f"mprov_jobserver.plugins.{mod.replace('-', '_')}"])
+
               mod_cls = getattr(mprov_jobserver.plugins, mod.replace('-', '_'))
               mod_cls = getattr(mod_cls, mod.replace('-', '_'))
               self.running_threads[mod] = mod_cls(self)
@@ -250,7 +270,7 @@ class JobServer ():
         'name': myHostname,
         'address': self.ip_address,
         'jobmodules': self.jobmodules,
-
+        'one_minute_load': os.getloadavg()[0]
     }
     # print(self.config_data)
     if 'image-server' in self.config_data:
@@ -307,11 +327,17 @@ class JobServer ():
       time.sleep(10)
       return
     self.sessionOk = True
-    # get the sock from the session
-    s = socket.fromfd(response.raw.fileno(), socket.AF_INET, socket.SOCK_STREAM)
-    # get the address from the socket
-    address = s.getsockname()
-    self.ip_address=address
+    if self.myaddress is not None:
+      if self.myaddress != '':
+        self.ip_address = self.myaddress
+      else:
+        print("Warning: No address set in config, attempting autodetection.  This may not work right...")
+        # get the sock from the session
+        s = socket.fromfd(response.raw.fileno(), socket.AF_INET, socket.SOCK_STREAM)
+        # get the address from the socket
+        address = s.getsockname()
+        self.ip_address=address
+      
     # if we get a response.status_code == 200, we're ok.  If not,
     # our auth failed.
     return response.status_code == 200
